@@ -941,7 +941,8 @@ function startdo($db, $tels,$sendid, $goipid=0){
 						elseif($goipdb[$the][send]=="SEND" && $comm[2]==$goipnow[telid]){//發送失敗
 							$goipdb[$the]['telrow']['error'][]=$goipdb[$the]['id'];
 							$findokflag=0;
-							foreach($goipdb as $the1 => $goiptmp){
+							if(count($goipdb[$the]['telrow']['error'])<=1){ //重发过的就不再重发了
+							    foreach($goipdb as $the1 => $goiptmp){
 								if(!check_sms_remain_count($db,$goiptmp['id'],$goiptmp['name'])) continue;
 
 								if($goiptmp[send]=="OK" && $goiptmp[provider]==$goipsend[provider] && !in_array($goiptmp[id],$goipdb[$the]['telrow']['error']) ){
@@ -956,12 +957,13 @@ function startdo($db, $tels,$sendid, $goipid=0){
 									dolastsend( $goipdb[$the1],$len,$msg);
 									break;
 								}
-							}
+							    }
 						
-							if(!$findokflag){
+							    if(!$findokflag){
 								array_push($errortels[$goipsend[provider]], $goipdb[$the][telrow]);
 								$db->query("delete from sends where id=$goipnow[telid]");
 								//array_push($tels[$goipsend[provider]], $goipsend[tel]); //壓回
+							    }
 							}
 							
 							$goipdb[$the]['send']="OK";//結束了
