@@ -7,8 +7,8 @@ var pickMode ={
 "day":4, 
 "month":5, 
 "year":6 }; 
-var topY=0,leftX=0; //自定义定位偏移量 2007-02-11 由 寒羽枫添加 
-//选择日期 → 由 寒羽枫 2007-06-10 添加，通过 ID 来选日期 
+var topY=0,leftX=0; //自定义定位偏移量 2007-02-11 添加 
+//选择日期 →  2007-06-10 添加，通过 ID 来选日期 
 function SelectDateById(id,strFormat,x,y) 
 { 
 var obj = document.getElementById(id); 
@@ -18,11 +18,11 @@ if(obj.onclick != null){obj.onclick();}
 else if(obj.click != null){obj.click();} 
 else{SelectDate(obj,strFormat,x,y)} 
 } 
-//选择日期 → 由 寒羽枫 2006-06-25 添加 
+//选择日期 →  2006-06-25 添加 
 function SelectDate(obj,strFormat,x,y) 
 { 
 leftX =(x == null) ? leftX : x; 
-topY =(y == null) ? topY : y;//自定义定位偏移量 2007-02-11 由 寒羽枫添加 
+topY =(y == null) ? topY : y;//自定义定位偏移量 2007-02-11 添加 
 if(document.getElementById("ContainerPanel")==null){InitContainerPanel();} 
 var date = new Date(); 
 var by = date.getFullYear()-50; //最小值 → 50 年前 
@@ -44,7 +44,7 @@ cal.show(obj);
 * 返回日期 
 * @param d the delimiter 
 * @param p the pattern of your date 
-2006-06-25 由 寒羽枫 修改为根据用户指定的 style 来确定； 
+2006-06-25  修改为根据用户指定的 style 来确定； 
 */ 
 String.prototype.toDate = function(style) { 
 var y = this.substring(style.indexOf('y'),style.lastIndexOf('y')+1);//年 
@@ -93,7 +93,7 @@ RegExp.$1.length == 1 ? o[k] :
 } 
 return style; 
 } 
-//2007-09-14 由寒羽枫添加返回所选日期 
+//2007-09-14 添加返回所选日期 
 Calendar.prototype.ReturnDate = function(dt) { 
 if (this.dateControl != null){this.dateControl.value = dt;} 
 calendar.hide(); 
@@ -146,7 +146,7 @@ this.second = this.date.getSeconds();
 this.colors = { 
 "cur_word" : "#FFFFFF", //当日日期文字颜色 
 "cur_bg" : "#00FF00", //当日日期单元格背影色 
-"sel_bg" : "#FFCCCC", //已被选择的日期单元格背影色 2006-12-03 寒羽枫添加 
+"sel_bg" : "#FFCCCC", //已被选择的日期单元格背影色 2006-12-03 添加 
 "sun_word" : "#FF0000", //星期天文字颜色 
 "sat_word" : "#0000FF", //星期六文字颜色 
 "td_word_light" : "#333333", //单元格文字颜色 
@@ -188,7 +188,7 @@ Calendar.language = {
 Calendar.prototype.draw = function() { 
 calendar = this; 
 var mvAry = []; 
-//mvAry[mvAry.length] = ' <form name="calendarForm" style="margin: 0px;">'; //因 <form> 不能嵌套， 2006-12-01 由寒羽枫改用 Div 
+//mvAry[mvAry.length] = ' <form name="calendarForm" style="margin: 0px;">'; //因 <form> 不能嵌套， 2006-12-01 改用 Div 
 mvAry[mvAry.length] = ' <div name="calendarForm" style="margin: 0px;">'; 
 mvAry[mvAry.length] = ' <table width="100%" border="0" cellpadding="0" cellspacing="1" style="font-size:12px;">'; 
 mvAry[mvAry.length] = ' <tr>'; 
@@ -247,7 +247,7 @@ mvAry[mvAry.length] = ' <input name="calendarClose" type="button" id="calendarCl
 mvAry[mvAry.length] = ' </div>'; 
 mvAry[mvAry.length] = ' </div>'; 
 this.panel.innerHTML = mvAry.join(""); 
-/**//**//**//******** 以下代码由寒羽枫 2006-12-01 添加 **********/ 
+/**//**//**//******** 以下代码 2006-12-01 添加 **********/ 
 var obj = this.getElementById("prevMonth"); 
 obj.onclick = function () {calendar.goPrevMonth(calendar);} 
 obj.onblur = function () {calendar.onblur();} 
@@ -258,7 +258,7 @@ obj.onblur = function () {calendar.onblur();}
 this.nextMonth= obj; 
 obj = this.getElementById("calendarClear"); 
 obj.onclick = function () 
-{ calendar.ReturnDate(""); /*calendar.dateControl.value = "";calendar.hide();*///2007-09-14 由寒羽枫注释 
+{ calendar.ReturnDate(""); /*calendar.dateControl.value = "";calendar.hide();*///2007-09-14 注释 
 } 
 this.calendarClear = obj; 
 obj = this.getElementById("calendarClose"); 
@@ -297,7 +297,7 @@ this.calendarToday = obj;
 } 
 //年份下拉框绑定数据 
 Calendar.prototype.bindYear = function() { 
-var cy = this.calendarYear;//2006-12-01 由寒羽枫修改 
+var cy = this.calendarYear;//2006-12-01 修改 
 cy.length = 0; 
 for (var i = this.beginYear; i <= this.endYear; i++){ 
 cy.options[cy.length] = new Option(i + Calendar.language["year"][this.lang], i); 
@@ -305,7 +305,7 @@ cy.options[cy.length] = new Option(i + Calendar.language["year"][this.lang], i);
 } 
 //月份下拉框绑定数据 
 Calendar.prototype.bindMonth = function() { 
-var cm = this.calendarMonth;//2006-12-01 由寒羽枫修改 
+var cm = this.calendarMonth;//2006-12-01 修改 
 cm.length = 0; 
 for (var i = 0; i < 12; i++){ 
 cm.options[cm.length] = new Option(Calendar.language["months"][this.lang][i], i); 
@@ -370,7 +370,7 @@ this.bindData();
 } 
 //改变SELECT选中状态 
 Calendar.prototype.changeSelect = function() { 
-var cy = this.calendarYear;//2006-12-01 由寒羽枫修改 
+var cy = this.calendarYear;//2006-12-01 修改 
 var cm = this.calendarMonth; 
 var ch = this.calendarHour; 
 var cM = this.calendarMinute; 
@@ -385,7 +385,7 @@ cs[this.second].selected =true;
 } 
 //更新年、月 
 Calendar.prototype.update = function (e){ 
-this.year = e.calendarYear.options[e.calendarYear.selectedIndex].value;//2006-12-01 由寒羽枫修改 
+this.year = e.calendarYear.options[e.calendarYear.selectedIndex].value;//2006-12-01 修改 
 this.month = e.calendarMonth.options[e.calendarMonth.selectedIndex].value; 
 this.date = new Date(this.year, this.month, 1); 
 //this.changeSelect(); 
@@ -444,7 +444,7 @@ calendar.day = this.innerHTML;
 calendar.selectedDayTD = this; //2009-03-03 记录已选中的日子 
 } 
 } 
-tds[i].style.cursor ="pointer"; //2007-08-06 由寒羽枫添加，鼠标变成手指状 
+tds[i].style.cursor ="pointer"; //2007-08-06 添加，鼠标变成手指状 
 tds[i].onmouseover = function () { 
 this.style.backgroundColor = calendar.colors["td_bg_over"]; 
 } 
@@ -498,7 +498,7 @@ throw new Error("arguments[0] is necessary")
 } 
 this.dateControl = dateObj; 
 var now = new Date(); 
-this.date = (dateObj.value.length > 0) ? new Date(dateObj.value.toDate(this.dateFormatStyle)) : now.format(this.dateFormatStyle).toDate(this.dateFormatStyle) ;//2008-01-29 寒羽枫添加 → 若为空则根据dateFormatStyle初始化日期 
+this.date = (dateObj.value.length > 0) ? new Date(dateObj.value.toDate(this.dateFormatStyle)) : now.format(this.dateFormatStyle).toDate(this.dateFormatStyle) ;//2008-01-29 添加 → 若为空则根据dateFormatStyle初始化日期 
 if(this.panel.innerHTML==""||cal.dateFormatStyleOld != cal.dateFormatStyle)//2008-01-29 把构造表格放在此处，2009-03-03 若请示的样式改变，则重新初始化 
 { 
 this.draw(); 
@@ -522,9 +522,9 @@ popControl = dateObj;
 var xy = this.getAbsPoint(popControl); 
 //this.panel.style.left = xy.x + "px"; 
 //this.panel.style.top = (xy.y + dateObj.offsetHeight) + "px"; 
-this.panel.style.left = (xy.x + leftX)+ "px"; //由寒羽枫 2007-02-11 修改 → 加入自定义偏移量 
+this.panel.style.left = (xy.x + leftX)+ "px"; // 2007-02-11 修改 → 加入自定义偏移量 
 this.panel.style.top = (xy.y + topY + dateObj.offsetHeight) + "px"; 
-//由寒羽枫 2006-06-25 修改 → 把 visibility 变为 display，并添加失去焦点的事件 //this.setDisplayStyle("select", "hidden"); 
+// 2006-06-25 修改 → 把 visibility 变为 display，并添加失去焦点的事件 //this.setDisplayStyle("select", "hidden"); 
 //this.panel.style.visibility = "visible"; 
 //this.container.style.visibility = "visible"; 
 this.panel.style.display = ""; 
@@ -554,11 +554,11 @@ this.panel.style.display = "none";
 this.container.style.display = "none"; 
 isFocus=false; 
 } 
-//焦点转移时隐藏日历 → 由寒羽枫 2006-06-25 添加 
+//焦点转移时隐藏日历 →  2006-06-25 添加 
 Calendar.prototype.onblur = function() { 
 if(!isFocus){this.hide();} 
 } 
-//以下由寒羽枫 2007-07-26 修改 → 确保日历容器节点在 body 最后，否则 FireFox 中不能出现在最上方 
+//以下 2007-07-26 修改 → 确保日历容器节点在 body 最后，否则 FireFox 中不能出现在最上方 
 function InitContainerPanel() //初始化容器 
 { 
 var str = '<div id="calendarPanel" style="position: absolute;display: none;z-index:9999; background-color: #FFFFFF;border: 1px solid #CCCCCC;width:175px;font-size:12px;"></div>'; 
@@ -575,4 +575,4 @@ div.id = "ContainerPanel";
 div.style.display ="none"; 
 document.body.appendChild(div); 
 }//调用calendar.show(dateControl, popControl); 
-//-->
\ No newline at end of file
+//-->
