@@ -179,7 +179,7 @@ for(;;){
                         $ussdmsg=implode(" ", $comm);
                         if($ussdmsg != "USSD send failed!"){
 				$ussdmsg=str_replace("@", "", $ussdmsg);
-				$ussdmsg=mysql_real_escape_string($ussdmsg);
+				//$ussdmsg=mysql_real_escape_string($ussdmsg);
                                 if(!$debug) echo "OK $ussdmsg";
                                 ok_over($_REQUEST[TERMID], $_REQUEST['USSDMSG'], $ussdmsg);
                         }
