@@ -144,7 +144,7 @@ Install_When_LAMP_Installed_By_Normal()
 #set default apache config path and Create symbolic link for mysql socket file if need
 if [ ${DISTRO} = "Debian" ] || [ ${DISTRO} = "Ubuntu" ];then
 	APACHE_PATH="/etc/apache2/sites-enabled"
-	[ ! -L /var/lib/mysql/mysql.sock ] && ln -s /var/run/mysqld/mysqld.sock /var/lib/mysql/mysql.sock 
+	[ -L /var/lib/mysql/mysql.sock ] && ln -s /var/run/mysqld/mysqld.sock /var/lib/mysql/mysql.sock 
 else
 	APACHE_PATH="/etc/httpd/conf.d"
 fi
